==> RsSmw-4.90.49.49-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gnss/Receiver/V/Hil/Itype.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Itype:
	"""Itype commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("itype", core, parent)

	def set(self, interface_type: enums.HilIfc, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: driver.source.bb.gnss.receiver.v.hil.itype.set(interface_type = enums.HilIfc.SCPI, vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMW and the control application. \n
			:param interface_type: SCPI| UDP
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')"""
		param = Conversions.enum_scalar_to_str(interface_type, enums.HilIfc)
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe {param}')

	# noinspection PyTypeChecker
	def get(self, vehicle=repcap.Vehicle.Default) -> enums.HilIfc:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: value: enums.HilIfc = driver.source.bb.gnss.receiver.v.hil.itype.get(vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMW and the control application. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: interface_type: SCPI| UDP"""
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe?')
		return Conversions.str_to_scalar_enum(response, enums.HilIfc)

==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gnss/Receiver/V/Hil/Itype.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Itype:
	"""Itype commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("itype", core, parent)

	def set(self, interface_type: enums.HilIfc, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: driver.source.bb.gnss.receiver.v.hil.itype.set(interface_type = enums.HilIfc.SCPI, vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMW and the control application. \n
			:param interface_type: SCPI| UDP
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.enum_scalar_to_str(interface_type, enums.HilIfc)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe {param}')

	# noinspection PyTypeChecker
	def get(self, vehicle=repcap.Vehicle.Default) -> enums.HilIfc:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: value: enums.HilIfc = driver.source.bb.gnss.receiver.v.hil.itype.get(vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMW and the control application. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: interface_type: SCPI| UDP"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe?')
		return Conversions.str_to_scalar_enum(response, enums.HilIfc)
